==> kubernetes-model-core-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/PodConditionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodConditionBuilder extends PodConditionFluentImpl<PodConditionBuilder> implements VisitableBuilder<PodCondition,PodConditionBuilder>{
  public PodConditionBuilder() {
    this(false);
  }
  public PodConditionBuilder(Boolean validationEnabled) {
    this(new PodCondition(), validationEnabled);
  }
  public PodConditionBuilder(PodConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public PodConditionBuilder(PodConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodCondition(), validationEnabled);
  }
  public PodConditionBuilder(PodConditionFluent<?> fluent,PodCondition instance) {
    this(fluent, instance, false);
  }
  public PodConditionBuilder(PodConditionFluent<?> fluent,PodCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withLastProbeTime(instance.getLastProbeTime());
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodConditionBuilder(PodCondition instance) {
    this(instance,false);
  }
  public PodConditionBuilder(PodCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withLastProbeTime(instance.getLastProbeTime());
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodConditionFluent<?> fluent;
  Boolean validationEnabled;
  public PodCondition build() {
    PodCondition buildable = new PodCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/PodConditionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodConditionBuilder extends PodConditionFluent<PodConditionBuilder> implements VisitableBuilder<PodCondition,PodConditionBuilder>{
  public PodConditionBuilder() {
    this(false);
  }
  public PodConditionBuilder(Boolean validationEnabled) {
    this(new PodCondition(), validationEnabled);
  }
  public PodConditionBuilder(PodConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public PodConditionBuilder(PodConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodCondition(), validationEnabled);
  }
  public PodConditionBuilder(PodConditionFluent<?> fluent,PodCondition instance) {
    this(fluent, instance, false);
  }
  public PodConditionBuilder(PodConditionFluent<?> fluent,PodCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PodCondition());

    if (instance != null) {
      fluent.withLastProbeTime(instance.getLastProbeTime());
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
      fluent.withLastProbeTime(instance.getLastProbeTime());
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodConditionBuilder(PodCondition instance) {
    this(instance,false);
  }
  public PodConditionBuilder(PodCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PodCondition());

    if (instance != null) {
      this.withLastProbeTime(instance.getLastProbeTime());
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
      this.withLastProbeTime(instance.getLastProbeTime());
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodConditionFluent<?> fluent;
  Boolean validationEnabled;
  public PodCondition build() {
    PodCondition buildable = new PodCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
